"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFilesFromBranchDiff = getFilesFromBranchDiff;
exports.getLintReportPath = getLintReportPath;
exports.getRootGitPath = getRootGitPath;
exports.getStagedFiles = getStagedFiles;
exports.resolveBranchDiffPath = resolveBranchDiffPath;
var _path = _interopRequireDefault(require("path"));
var _child_process = require("child_process");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function getFilesFromBranchDiff(diffJson) {
  if (!diffJson) {
    return null;
  }
  var rootPath = getRootGitPath();
  return diffJson === null || diffJson === void 0 ? void 0 : diffJson.diffs.map(function (diff) {
    return _path["default"].resolve(rootPath, diff === null || diff === void 0 ? void 0 : diff.new_path);
  });
}
function getLintReportPath(reportPath) {
  var jsonReportPath = reportPath || _path["default"].resolve(process.cwd(), "uat", "lint-report", "lintReport.json");
  return jsonReportPath;
}
function resolveBranchDiffPath(diffJsonPath) {
  return _path["default"].resolve(diffJsonPath);
}
function getStagedFiles() {
  var command = "git diff --cached -U0 HEAD --name-only";
  var child = (0, _child_process.spawnSync)(command, {
    shell: true
  });
  var diffFiles = child.stdout.toString().split("\n").map(function (filePath) {
    return _path["default"].resolve(getRootGitPath(), filePath);
  });
  diffFiles.pop(); // remove last empty string
  return diffFiles;
}
function getRootGitPath() {
  var childProcess = (0, _child_process.spawnSync)("git", ["rev-parse", "--show-toplevel"], {
    shell: true
  });
  return childProcess.stdout.toString().split("\n").filter(Boolean).pop();
}