"use strict";

var _rootPath = require("../../utils/rootPath");
var _path = _interopRequireDefault(require("path"));
var _child_process = require("child_process");
var _getFileUtils = require("../eslint/getFileUtils");
var _runSonar = require("./runSonar");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function getSonarHostUrl() {
  var sonarqube_host_url = "https://serverlinter-np.zohodesk.csez.zohocorpin.com/";
  return sonarqube_host_url;
}
function getProjectName(cliArgument) {
  var _cliArgument$repo = cliArgument.repo,
    repo = _cliArgument$repo === void 0 ? null : _cliArgument$repo,
    branch = cliArgument.branch,
    username = cliArgument.username,
    executeFrom = cliArgument.executeFrom,
    executeVia = cliArgument.executeVia;
  var project_name = repo && branch && username ? "".concat(repo, "_").concat(branch, "_").concat(username) : "UAT_Testing";
  if (executeFrom === "pre-commit" || executeVia == "method") {
    project_name = "".concat(getProjectNameFrmGit(), "_pre-commit");
  }
  return project_name;
}
function getTestFiles(cliArgument) {
  var _cliArgument$diffPath = cliArgument.diffPath,
    diffPath = _cliArgument$diffPath === void 0 ? null : _cliArgument$diffPath;
  if (!diffPath) {
    return ["".concat(_path["default"].resolve(process.cwd(), "uat"))].join(",");
  }
  var testFiles = (0, _runSonar.filterSpecAndFeatureFiles)(getLintFiles_preCommit_ci(cliArgument)).stepFilesPath;
  return testFiles.join(",");
}
function getSourceFiles(cliArgument) {
  var _cliArgument$diffPath2 = cliArgument.diffPath,
    diffPath = _cliArgument$diffPath2 === void 0 ? null : _cliArgument$diffPath2;
  if (!diffPath) {
    return [" "].join("");
  }
  var sourceFiles = (0, _runSonar.filterSpecAndFeatureFiles)(getLintFiles_preCommit_ci(cliArgument)).featureFilesPath;
  return sourceFiles;
}
function getLintFiles_preCommit_ci(cliArgument) {
  var executeFrom = cliArgument.executeFrom,
    diffPath = cliArgument.diffPath,
    _cliArgument$stagedFi = cliArgument.stagedFiles,
    stagedFiles = _cliArgument$stagedFi === void 0 ? null : _cliArgument$stagedFi,
    _cliArgument$executeV = cliArgument.executeVia,
    executeVia = _cliArgument$executeV === void 0 ? null : _cliArgument$executeV;
  if (executeVia == 'method' && stagedFiles !== null && stagedFiles !== void 0 && stagedFiles.length) {
    return stagedFiles;
  }
  if (executeFrom === "pre-commit") {
    return (0, _getFileUtils.getStagedFiles)();
  }
  return (0, _getFileUtils.getFilesFromBranchDiff)(require((0, _getFileUtils.resolveBranchDiffPath)(diffPath)));
}
function getSonarProperties(cliObjects) {
  // lintJsonPath, stagedFiles,executeVia, diffFiles
  var login = cliObjects.login,
    password = cliObjects.password,
    _cliObjects$lintJsonP = cliObjects.lintJsonPath,
    lintJsonPath = _cliObjects$lintJsonP === void 0 ? null : _cliObjects$lintJsonP;
  var sonarqube_host_url = getSonarHostUrl(cliObjects);
  var sonar_scanner_path = (0, _rootPath.getSonarJarPath)();
  var _getCredentials = getCredentials(login, password),
    Dlogin = _getCredentials.Dlogin,
    Dpassword = _getCredentials.Dpassword;
  var project_name = getProjectName(cliObjects);
  var resultFilesPath = getTestFiles(cliObjects);
  var source_directories = getSourceFiles(cliObjects);
  var command = ["-jar", sonar_scanner_path, "-Dsonar.host.url=".concat(sonarqube_host_url), "-Dsonar.projectKey=".concat(project_name), "-Dsonar.login=".concat(Dlogin), "-Dsonar.password=".concat(Dpassword), "-Dsonar.sources=".concat(source_directories), "-Dsonar.tests=".concat(resultFilesPath), "-Dsonar.language=js", "-Dsonar.working.directory=".concat(getSonarArtifactsDir()), "-Dsonar.eslint.reportPaths=".concat((0, _getFileUtils.getLintReportPath)(lintJsonPath)), "-Dsonar.javascript.lcov.reportPaths=coverage/lcov-report/lcov.info"];
  return command;
}
function getProjectNameFrmGit() {
  var $repoName = getRepoName();
  var $branchName = getBranchName();
  var $username = getGitUsername();
  return $repoName && $branchName && $username ? "".concat($repoName, "_").concat($branchName, "_").concat($username) : "desk_default_project";
}
function getGitUsername() {
  var userName = getSpawnOutput("git", ["config", "user.email"]);
  return userName.pop().split("@")[0];
}
function getRepoName() {
  var repoName = getSpawnOutput("git", ["remote", "get-url", "origin"]);
  return repoName.pop().split("/").pop().split(".")[0];
}
function getBranchName() {
  // git rev-parse --abbrev-ref HEAD
  var branchName = getSpawnOutput("git", ["rev-parse", "--abbrev-ref", "HEAD"]); // to get current branch
  return branchName.shift().trim();
}
function getSpawnOutput(command) {
  var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var demon_process = (0, _child_process.spawnSync)(command, params, {
    shell: true
  });
  return demon_process.stdout.toString().split("\n").filter(Boolean);
}
function getCredentials(login, password) {
  if (login && password) {
    return {
      Dlogin: login,
      Dpassword: password
    };
  }
  return {
    Dlogin: "developer",
    Dpassword: "developer"
  };
}
function getSonarArtifactsDir() {
  return _path["default"].resolve(process.cwd(), "uat", "lint-report", ".scannerwork");
}
module.exports = {
  getBranchName: getBranchName,
  getCredentials: getCredentials,
  getFilesFromBranchDiff: _getFileUtils.getFilesFromBranchDiff,
  getGitUsername: getGitUsername,
  getRepoName: getRepoName,
  getSonarProperties: getSonarProperties,
  getSonarHostUrl: getSonarHostUrl,
  getSpawnOutput: getSpawnOutput
};