"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSonarAnalysis = executeSonarAnalysis;
exports.filterSpecAndFeatureFiles = filterSpecAndFeatureFiles;
var _child_process = require("child_process");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../../utils/logger");
var _popUpCli = require("../popUpCli");
var _getSonarProperties = require("./getSonarProperties");
// Js script to start sonar Server

/**
 *  cli cmd :
 *  npx ZDTestingFramework lint -- --executeFrom=ci --diffPath="" --repo="deskClientApp" --branch="" --username=""
 */

function executeSonarAnalysis(cliParams) {
  var cliObjects = cliParams;
  var _cliObjects$executeFr = cliObjects.executeFrom,
    executeFrom = _cliObjects$executeFr === void 0 ? null : _cliObjects$executeFr;
  var command = (0, _getSonarProperties.getSonarProperties)(cliObjects);
  var child_process = (0, _child_process.spawn)("java", command);
  child_process.stdout.on("data", function (data) {
    _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, data);
  });
  child_process.stderr.on("data", function (errorOut) {
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", function (error) {
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, "Error: ".concat(error.message));
  });
  child_process.on("close", function (code) {
    _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, "Report to Server  Status - ".concat(code === 0 ? "Success" : "Failure"));
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    _logger.Logger.log(_logger.Logger.INFO_TYPE, "report url - ".concat((0, _sonarReportSummary.getSummaryOfLint)(cliParams).reportUrl));
    if (executeFrom == "pre-commit") {
      _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, "lint triggered from pre-commit ...");
      if (!(0, _sonarReportSummary.getLintStatus)().status && (0, _sonarReportSummary.getLintStatus)().message == "failed") {
        _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "rules violated .. ");
        (0, _popUpCli.showMsgPopUp)("IssueFound");
        process.exit(1);
      } else {
        (0, _popUpCli.showMsgPopUp)("NoIssueFound");
      }
    }
  });
}
function filterSpecAndFeatureFiles(resultJson) {
  return resultJson.reduce(function (filesPath, fileReport) {
    if (fileReport.includes(".feature")) {
      filesPath.featureFilesPath.push(fileReport);
    } else {
      filesPath.stepFilesPath.push(fileReport);
    }
    return filesPath;
  }, {
    stepFilesPath: [],
    featureFilesPath: []
  });
}