import path from 'path'
import { getModifiedLines } from '../getModifiedLines';
import { getRootGitPath } from './getFileUtils';
function filterReportBasedBranchDiff(reportJson, diffJson) {
  return new Promise((resolve) => {
    if (!diffJson) {
      Logger.log(Logger.FAILURE_TYPE, "git diff json is not given ...");
      resolve(false);
    }
    const impactLineMap = filterDiffJson(diffJson);
    reportJson = reportJson.filter((fileReport) => {
      const isImpactFile = fileReport.filePath;
      if (!isImpactFile || isImpactFile.includes(".feature")) {
        return false;
      }
      if (impactLineMap.get(isImpactFile)?.length !== 0) {
        fileReport.messages = fileReport.messages.filter((errorMsg) => {
          if (impactLineMap.get(isImpactFile).includes(errorMsg.line)) {
            return true;
          }
          return false;
        });
        return true;
      }
    });
    resolve(reportJson);
  });
}

function filterDiffJson(diffJson) {
  const diffFilesMap = new Map();
  diffJson?.diffs?.forEach((diff) => {
    const diffPathKey = path.resolve(getRootGitPath(), diff.new_path);
    if (diffPathKey === undefined) {
      return;
    }
    if (diffPathKey) {
      diffFilesMap.set(diffPathKey, getModifiedLines(diff.diff).modifiedLines);
    }
  });
  return diffFilesMap;
}

export { filterDiffJson, filterReportBasedBranchDiff };
