import { spawn } from "child_process";
import path from "path";
import { Logger } from "../../utils/logger";
import { writeFileContents } from "../../utils/fileUtils";
import { getFilesFromBranchDiff, getLintReportPath, getStagedFiles, resolveBranchDiffPath } from "./getFileUtils";
import { filterReportBasedBranchDiff } from "./filterReports";
function executeLintAnalysis(cliParams) {
  const { diffPath = null, executeFrom = null, lintJsonPath = null, stagedFiles = null, executeVia = null } = cliParams;
  const format = "json";
  const reportPath = getLintReportPath();
  const branch_diff_json = diffPath ? require(resolveBranchDiffPath(diffPath)) : null;
  const filteredDiffFiles = getFilesFromBranchDiff(branch_diff_json);
  var lintFiles = !filteredDiffFiles ? [ path.resolve(process.cwd(), "uat")] : filteredDiffFiles;
  if (executeFrom === "pre-commit") {
    lintFiles = getStagedFiles();
  }

  if(executeFrom == 'pre-commit' && executeVia == 'method' && stagedFiles?.length ){
    lintFiles = stagedFiles
  }
  return new Promise((resolve) => {
    const command = [
      "eslint",
      lintFiles.join(" "),
      `--format=${format}`,
      "-o",
      `${lintJsonPath || reportPath}`,
    ];
    try {
      const lint_process = spawn("npx", command, {
        shell: true,
        cwd: process.cwd(),
      });
      lint_process.stdout.on("data", (data) => {
        Logger.log(Logger.INFO_TYPE, data);
      });
      lint_process.stderr.on("error", (err) => {
        Logger.log(Logger.FAILURE_TYPE, err);
      });
      lint_process.on("error", (errors) => {
        Logger.log(Logger.FAILURE_TYPE, errors);
      });
      lint_process.on("close", async (onclose) => {
        if (diffPath && !(filteredDiffFiles.length === 0)) {
          const filteredReportJson = await filterReportBasedBranchDiff(require(reportPath),branch_diff_json);
          writeFileContents(reportPath, JSON.stringify(filteredReportJson));
        }
        resolve({ status: "success" });
      });
    } catch (error) {
      Logger.log(Logger.INFO_TYPE, error);
      Logger.log(Logger.FAILURE_TYPE, "Execution Failed");
    }
  });
}



export {
  executeLintAnalysis
};
