import { getSonarJarPath } from "../../utils/rootPath";
import path from "path";
import {spawnSync} from 'child_process'
import {
  getFilesFromBranchDiff,
  resolveBranchDiffPath,
} from "../eslint/getFileUtils";
import {
  filterSpecAndFeatureFiles,
} from "./runSonar";
import { getLintReportPath, getStagedFiles } from "../eslint/getFileUtils";

function getSonarHostUrl() {
  var sonarqube_host_url =
    "https://serverlinter-np.zohodesk.csez.zohocorpin.com/";
  return sonarqube_host_url;
}
function getProjectName(cliArgument) {
  const { repo = null,branch,username,executeFrom, executeVia } = cliArgument
  var project_name =
    repo && branch && username
      ? `${repo}_${branch}_${username}`
      : "UAT_Testing";
  if (executeFrom === "pre-commit" || executeVia == "method") {
    project_name = `${getProjectNameFrmGit()}_pre-commit`;
  }

  return project_name;
}

function getTestFiles(cliArgument) {
  const { diffPath = null } = cliArgument;
  if (!diffPath) {
    return [`${path.resolve(process.cwd(), "uat")}`].join(",");
  }
  var testFiles = filterSpecAndFeatureFiles(
    getLintFiles_preCommit_ci(cliArgument)
  ).stepFilesPath;
  return testFiles.join(",");
}

function getSourceFiles(cliArgument) {
  const { diffPath = null  } = cliArgument;
  if (!diffPath ) {
    return [" "].join("");
  }
  var sourceFiles = filterSpecAndFeatureFiles(
    getLintFiles_preCommit_ci(cliArgument)
  ).featureFilesPath;
  return sourceFiles;
}

function getLintFiles_preCommit_ci(cliArgument) {
  var { executeFrom, diffPath, stagedFiles = null, executeVia = null } = cliArgument;
  if(executeVia == 'method' && stagedFiles?.length){
    return stagedFiles
  }
  if (executeFrom === "pre-commit") {
    return getStagedFiles();
  }
  return getFilesFromBranchDiff(require(resolveBranchDiffPath(diffPath)));
}

function getSonarProperties(cliObjects) {
  // lintJsonPath, stagedFiles,executeVia, diffFiles
  const { login, password, lintJsonPath = null } = cliObjects;
  const sonarqube_host_url = getSonarHostUrl(cliObjects);
  const sonar_scanner_path = getSonarJarPath();
  const { Dlogin, Dpassword } = getCredentials(login, password);
  var project_name = getProjectName(cliObjects);
  var resultFilesPath =  getTestFiles(cliObjects);
  var source_directories = getSourceFiles(cliObjects);
  const command = [
    "-jar",
    sonar_scanner_path,
    `-Dsonar.host.url=${sonarqube_host_url}`,
    `-Dsonar.projectKey=${project_name}`,
    `-Dsonar.login=${Dlogin}`,
    `-Dsonar.password=${Dpassword}`,
    `-Dsonar.sources=${source_directories}`,
    `-Dsonar.tests=${resultFilesPath}`,
    "-Dsonar.language=js",
    `-Dsonar.working.directory=${getSonarArtifactsDir()}`,
    `-Dsonar.eslint.reportPaths=${getLintReportPath(lintJsonPath)}`,
    "-Dsonar.javascript.lcov.reportPaths=coverage/lcov-report/lcov.info",
  ];
  return command;
}

function getProjectNameFrmGit() {
  let $repoName = getRepoName();
  let $branchName = getBranchName();
  let $username = getGitUsername();
  return $repoName && $branchName && $username
    ? `${$repoName}_${$branchName}_${$username}`
    : "desk_default_project";
}

function getGitUsername() {
  const userName = getSpawnOutput("git", ["config", "user.email"]);
  return userName.pop().split("@")[0];
}

function getRepoName() {
  const repoName = getSpawnOutput("git", ["remote", "get-url", "origin"]);
  return repoName.pop().split("/").pop().split(".")[0];
}

function getBranchName() {
  // git rev-parse --abbrev-ref HEAD
  var branchName = getSpawnOutput("git", ["rev-parse", "--abbrev-ref", "HEAD"]); // to get current branch
  return branchName.shift().trim();
}

function getSpawnOutput(command, params = []) {
  const demon_process = spawnSync(command, params, { shell: true });
  return demon_process.stdout.toString().split("\n").filter(Boolean);
}

function getCredentials(login, password) {
  if (login && password) {
    return {
      Dlogin: login,
      Dpassword: password,
    };
  }
  return {
    Dlogin: "developer",
    Dpassword: "developer",
  };
}

function getSonarArtifactsDir() {
  return path.resolve(process.cwd(), "uat", "lint-report", ".scannerwork");
}


module.exports = {
  getBranchName,
  getCredentials,
  getFilesFromBranchDiff,
  getGitUsername,
  getRepoName,
  getSonarProperties,
  getSonarHostUrl,
  getSpawnOutput
}