// Js script to start sonar Server

/**
 *  cli cmd :
 *  npx ZDTestingFramework lint -- --executeFrom=ci --diffPath="" --repo="deskClientApp" --branch="" --username=""
 */
import { spawn,  } from "child_process";
import { getLintStatus, getSummaryOfLint, writeSummaryOfLint } from "./sonarReportSummary";
import { Logger } from "../../utils/logger";
import { showMsgPopUp } from "../popUpCli";
import { getSonarProperties } from "./getSonarProperties";

function executeSonarAnalysis(cliParams) {
  const cliObjects = cliParams
  const { executeFrom = null } = cliObjects;
  const command = getSonarProperties(cliObjects);
  const child_process = spawn("java", command);

  child_process.stdout.on("data", (data) => {
    Logger.log(Logger.SUCCESS_TYPE, data);
  });

  child_process.stderr.on("data", (errorOut) => {
    Logger.error(Logger.FAILURE_TYPE, errorOut);
  });

  child_process.on("error", (error) => {
    Logger.error(Logger.FAILURE_TYPE, `Error: ${error.message}`);
  });

  child_process.on("close", (code) => {
    Logger.log(
      Logger.SUCCESS_TYPE,
      `Report to Server  Status - ${code === 0 ? "Success" : "Failure"}`
    );
    writeSummaryOfLint(cliParams);
    Logger.log(
      Logger.INFO_TYPE,
      `report url - ${getSummaryOfLint(cliParams).reportUrl}`
    );
    if (executeFrom == "pre-commit") {
      Logger.log(Logger.SUCCESS_TYPE, "lint triggered from pre-commit ...");
      if (!getLintStatus().status && getLintStatus().message == "failed") {
        Logger.log(Logger.FAILURE_TYPE, "rules violated .. ");
        showMsgPopUp("IssueFound");
        process.exit(1);
      } else {
        showMsgPopUp("NoIssueFound");
      }
    }
  });
}

function filterSpecAndFeatureFiles(resultJson) {
  return resultJson.reduce(
    (filesPath, fileReport) => {
      if (fileReport.includes(".feature")) {
        filesPath.featureFilesPath.push(fileReport);
      } else {
        filesPath.stepFilesPath.push(fileReport);
      }
      return filesPath;
    },
    { stepFilesPath: [], featureFilesPath: [] }
  );
}


export {
  executeSonarAnalysis,
  filterSpecAndFeatureFiles,
};
