import path from "path";
import { writeFileContents } from "../../utils/fileUtils";
import { getLintReportPath } from "../eslint/getFileUtils";
import { getProjectNameFrmGit } from "./getSonarProperties";

function getSummaryOfLint(cliParams) {
  const { repo, branch, username, executeFrom } = cliParams;
  var $projectName =
    repo && branch && username
      ? `${repo}_${branch}_${username}`
      : "UAT_Testing";
  if (executeFrom === "pre-commit") {
    $projectName = `${getProjectNameFrmGit()}_pre-commit`;
  }
  return {
    projectName: $projectName,
    reportUrl: `https://serverlinter-np.zohodesk.csez.zohocorpin.com/project/issues?id=${$projectName}&resolved=false`,
    jsonReportPath: getLintReportPath().toString(),
  };
}

function getLintStatus() {
  var reportStatus = true;
  const report = require(getLintReportPath());
  if (report.length == 0) {
    return {
      status: true,
      message: "passed",
    };
  }
  if (report.length != 0) {
    for (let i = 0; i < report.length; i++) {
      if (report[i].messages != 0) {
        reportStatus = false;
        break;
      }
    }
    if (reportStatus) {
      return { status: reportStatus, message: "passed" };
    }
    return { status: reportStatus, message: "failed" };
  }
}

function writeSummaryOfLint(cliParams) {
  writeFileContents(
    path.resolve(process.cwd(), "uat", "lint-report", "lint-summary.json"),
    JSON.stringify({ ...getSummaryOfLint(cliParams), ...getLintStatus() })
  );
}

export { writeSummaryOfLint, getSummaryOfLint, getLintStatus };
